@@ -61,18 +61,18 @@ static void dump_gas(const char *reg_name,
     const char *space_id[] = { "memory", "I/O", "PCI config space", "EC",
                                "SMBus" };
 
-    printk("%s GAS @ %p:\n", reg_name, reg);
+    printk(TBOOT_DETA"%s GAS @ %p:\n", reg_name, reg);
     if ( reg == NULL )
         return;
 
     if ( reg->space_id >= ARRAY_SIZE(space_id) )
-        printk("\t space_id: unsupported (%u)\n", reg->space_id);
+        printk(TBOOT_DETA"\t space_id: unsupported (%u)\n", reg->space_id);
     else
-        printk("\t space_id: %s\n", space_id[reg->space_id]);
-    printk("\t bit_width: %u\n", reg->bit_width);
-    printk("\t bit_offset: %u\n", reg->bit_offset);
-    printk("\t access_width: %u\n", reg->access_width);
-    printk("\t address: %Lx\n", reg->address);
+        printk(TBOOT_DETA"\t space_id: %s\n", space_id[reg->space_id]);
+    printk(TBOOT_DETA"\t bit_width: %u\n", reg->bit_width);
+    printk(TBOOT_DETA"\t bit_offset: %u\n", reg->bit_offset);
+    printk(TBOOT_DETA"\t access_width: %u\n", reg->access_width);
+    printk(TBOOT_DETA"\t address: %Lx\n", reg->address);
 }
 
 static inline struct acpi_rsdt *get_rsdt(void)
@@ -83,7 +83,7 @@ static inline struct acpi_rsdt *get_rsdt(void)
 static inline struct acpi_xsdt *get_xsdt(void)
 {
     if ( rsdp->rsdp_xsdt >= 0x100000000ULL ) {
-        printk("XSDT above 4GB\n");
+        printk(TBOOT_ERR"XSDT above 4GB\n");
         return NULL;
     }
     return (struct acpi_xsdt *)(uintptr_t)rsdp->rsdp_xsdt;
@@ -110,12 +110,12 @@ static bool find_rsdp_in_range(void *start, void *end)
         if ( memcmp(rsdp->rsdp1.signature, RSDP_SIG,
                     sizeof(rsdp->rsdp1.signature)) == 0 ) {
             if ( verify_acpi_checksum((uint8_t *)rsdp, RSDP_CHKSUM_LEN) ) {
-                printk("RSDP (v%u, %.6s) @ %p\n", rsdp->rsdp1.revision,
+                printk(TBOOT_DETA"RSDP (v%u, %.6s) @ %p\n", rsdp->rsdp1.revision,
                        rsdp->rsdp1.oemid, rsdp);
                 return true;
             }
             else {
-                printk("checksum failed.\n");
+                printk(TBOOT_ERR"checksum failed.\n");
                 return false;
             }
         }
@@ -137,7 +137,7 @@ static bool find_rsdp(void)
     if ( find_rsdp_in_range(RSDP_SCOPE2_LOW, RSDP_SCOPE2_HIGH) )
         return true;
 
-    printk("cann't find RSDP\n");
+    printk(TBOOT_ERR"cann't find RSDP\n");
     rsdp = NULL;
     return false;
 }
@@ -146,7 +146,7 @@ static bool find_rsdp(void)
 static struct acpi_table_header *find_table(const char *table_name)
 {
     if ( !find_rsdp() ) {
-        printk("no rsdp to use\n");
+        printk(TBOOT_ERR"no rsdp to use\n");
         return NULL;
     }
    
@@ -168,7 +168,7 @@ static struct acpi_table_header *find_table(const char *table_name)
         struct acpi_rsdt *rsdt = get_rsdt();
 
         if ( rsdt == NULL ) {
-            printk("rsdt is invalid.\n");
+            printk(TBOOT_ERR"rsdt is invalid.\n");
             return NULL;
         }
 
@@ -182,7 +182,7 @@ static struct acpi_table_header *find_table(const char *table_name)
         }
     }
 
-    printk("cann't find %s table.\n", table_name);
+    printk(TBOOT_ERR"cann't find %s table.\n", table_name);
     return NULL;
 }
 
@@ -196,7 +196,7 @@ bool save_vtd_dmar_table(void)
     /* find DMAR table and save it */
     g_dmar_table = (struct acpi_table_header *)get_vtd_dmar_table();
 
-    printk("DMAR table @ %p saved.\n", g_dmar_table);
+    printk(TBOOT_DETA"DMAR table @ %p saved.\n", g_dmar_table);
     return true;
 }
 
@@ -209,13 +209,13 @@ bool restore_vtd_dmar_table(void)
     /* find DMAR table first */
     hdr = (struct acpi_table_header *)get_vtd_dmar_table();
     if ( hdr != NULL ) {
-        printk("DMAR table @ %p is still there, skip restore step.\n", hdr);
+        printk(TBOOT_DETA"DMAR table @ %p is still there, skip restore step.\n", hdr);
         return true;
     }
 
     /* check saved DMAR table */
     if ( g_dmar_table == NULL ) {
-        printk("No DMAR table saved, abort restore step.\n");
+        printk(TBOOT_ERR"No DMAR table saved, abort restore step.\n");
         return false;
     }
 
@@ -224,7 +224,7 @@ bool restore_vtd_dmar_table(void)
 
     /* need to hide DMAR table while resume from S3 */
     g_hide_dmar = true;
-    printk("DMAR table @ %p restored.\n", hdr);
+    printk(TBOOT_DETA"DMAR table @ %p restored.\n", hdr);
     return true;
 }
 
@@ -234,20 +234,20 @@ bool remove_vtd_dmar_table(void)
 
     /* check whether it is needed */
     if ( !g_hide_dmar ) {
-        printk("No need to hide DMAR table.\n");
+        printk(TBOOT_DETA"No need to hide DMAR table.\n");
         return true;
     }
 
     /* find DMAR table */
     hdr = (struct acpi_table_header *)get_vtd_dmar_table();
     if ( hdr == NULL ) {
-        printk("No DMAR table, skip remove step.\n");
+        printk(TBOOT_DETA"No DMAR table, skip remove step.\n");
         return true;
     }
 
     /* remove DMAR table */
     hdr->signature[0] = '\0';
-    printk("DMAR table @ %p removed.\n", hdr);
+    printk(TBOOT_DETA"DMAR table @ %p removed.\n", hdr);
     return true;
 }
 
@@ -260,7 +260,7 @@ struct acpi_table_ioapic *get_acpi_ioapic_table(void)
 {
     struct acpi_madt *madt = get_apic_table();
     if ( madt == NULL ) {
-        printk("no MADT table found\n");
+        printk(TBOOT_ERR"no MADT table found\n");
         return NULL;
     }
 
@@ -272,14 +272,14 @@ struct acpi_table_ioapic *get_acpi_ioapic_table(void)
 
 		if ( entry->madt_lapic.apic_type == ACPI_MADT_IOAPIC ) {
 			if ( length != sizeof(entry->madt_ioapic) ) {
-                printk("APIC length error.\n");
+                printk(TBOOT_ERR"APIC length error.\n");
                 return NULL;
             }
             return (struct acpi_table_ioapic *)entry;
         }
 		entry = (void *)entry + length;
 	}
-    printk("no IOAPIC type.\n");
+    printk(TBOOT_ERR"no IOAPIC type.\n");
     return NULL;
 }
 
@@ -292,7 +292,7 @@ static bool write_to_reg(const tboot_acpi_generic_address_t *reg,
                          uint32_t val)
 {
     if ( reg->address >= 100000000ULL ) {
-        printk("GAS address >4GB (0x%Lx)\n", reg->address);
+        printk(TBOOT_ERR"GAS address >4GB (0x%Lx)\n", reg->address);
         return false;
     }
     uint32_t address = (uint32_t)reg->address;
@@ -309,7 +309,7 @@ static bool write_to_reg(const tboot_acpi_generic_address_t *reg,
                 outl(address, val);
                 return true;
             default:
-                printk("unsupported GAS bit width: %u\n", reg->bit_width);
+                printk(TBOOT_ERR"unsupported GAS bit width: %u\n", reg->bit_width);
                 return false;
         }
     }
@@ -325,12 +325,12 @@ static bool write_to_reg(const tboot_acpi_generic_address_t *reg,
                 writel(address, val);
                 return true;
             default:
-                printk("unsupported GAS bit width: %u\n", reg->bit_width);
+                printk(TBOOT_ERR"unsupported GAS bit width: %u\n", reg->bit_width);
                 return false;
         }
     }
 
-    printk("unsupported GAS addr space ID: %u\n", reg->space_id);
+    printk(TBOOT_ERR"unsupported GAS addr space ID: %u\n", reg->space_id);
     return false;
 }
 
@@ -338,7 +338,7 @@ static bool read_from_reg(const tboot_acpi_generic_address_t *reg,
                           uint32_t *val)
 {
     if ( reg->address >= 100000000ULL ) {
-        printk("GAS address >4GB (0x%Lx)\n", reg->address);
+        printk(TBOOT_ERR"GAS address >4GB (0x%Lx)\n", reg->address);
         return false;
     }
     uint32_t address = (uint32_t)reg->address;
@@ -353,9 +353,8 @@ static bool read_from_reg(const tboot_acpi_generic_address_t *reg,
                 return true;
             case 32:
                 *val = inl(address);
-                return true;
-            default:
-                printk("unsupported GAS bit width: %u\n", reg->bit_width);
+                return true; default:
+                printk(TBOOT_ERR"unsupported GAS bit width: %u\n", reg->bit_width);
                 return false;
         }
     }
@@ -371,12 +370,12 @@ static bool read_from_reg(const tboot_acpi_generic_address_t *reg,
                 *val = readl(address);
                 return true;
             default:
-                printk("unsupported GAS bit width: %u\n", reg->bit_width);
+                printk(TBOOT_ERR"unsupported GAS bit width: %u\n", reg->bit_width);
                 return false;
         }
     }
 
-    printk("unsupported GAS addr space ID: %u\n", reg->space_id);
+    printk(TBOOT_ERR"unsupported GAS addr space ID: %u\n", reg->space_id);
     return false;
 }
 
@@ -432,10 +431,10 @@ void set_s3_resume_vector(const tboot_acpi_sleep_info_t *acpi_sinfo,
         *(uint64_t *)(unsigned long)(acpi_sinfo->wakeup_vector) =
                                     resume_vector;
     else
-        printk("vector_width error.\n");
+        printk(TBOOT_WARN"vector_width error.\n");
 
-    acpi_printk("wakeup_vector_address = %llx\n", acpi_sinfo->wakeup_vector);
-    acpi_printk("wakeup_vector_value = %llxx\n", resume_vector);
+    acpi_printk(TBOOT_DETA"wakeup_vector_address = %llx\n", acpi_sinfo->wakeup_vector);
+    acpi_printk(TBOOT_DETA"wakeup_vector_value = %llxx\n", resume_vector);
 }
 
 /*
